@@ -20,22 +20,9 @@ def gen_uid(store, secret_def):
     # a secret directly
     # > 'store' is used in another way to specify where to retrieve the secret from
     # > 'key' is used to extract data from an already retrieved secret
-    filtered_keys = [secret_def[k] for k in sorted_keys if k not in ["key", "store"]]
+    filtered_keys = [
+        secret_def[k] for k in sorted_keys if k not in ["key", "store", "sensitive"]
+    ]
 
     # 3) generate the final string used as the unique ID
     return "-".join([store] + filtered_keys)
-
-
-def remove_duplicated_secrets(secrets):
-    res = {}
-    for k, value in secrets.items():
-        if type(value) == str:
-            res[k] = (k, value)
-            continue
-
-        uid = gen_uid(value["store"], value)
-        if uid in res:
-            continue
-        res[uid] = (k, value)
-
-    return {k: v for k, v in res.values()}
